#include "statebox.h"

#include <QBrush>
#include <QLinearGradient>

#include "math.h"

StateBox::StateBox():
       _text(),
       _outterborderColor(Qt::black),
       _outterborderPen(),
       _location(0,0),
       _dragStart(0,0),
       _gridSpace(10),
       _width(150),
       _height(100)
{
     _outterborderPen.setWidth(2);
     _outterborderPen.setColor(_outterborderColor);

    _text.setPlainText("text goes here");
    _text.setParentItem(this);


    this->setAcceptHoverEvents(true);


}

void StateBox::mouseMoveEvent(QGraphicsSceneDragDropEvent *event)
{
    event->setAccepted(false);
}

void StateBox::mousePressEvent(QGraphicsSceneDragDropEvent *event)
{
    event->setAccepted(false);
}

void StateBox::mouseReleaseEvent ( QGraphicsSceneMouseEvent * event )
{
    event->setAccepted(true);
   _location.setX( ( static_cast<int>(_location.x()) / _gridSpace) * _gridSpace );
   _location.setY( ( static_cast<int>(_location.y()) / _gridSpace) * _gridSpace );
   this->setPos(_location);
}

void StateBox::mousePressEvent ( QGraphicsSceneMouseEvent * event )
{
    event->setAccepted(true);

    _dragStart = event->pos();
}

void StateBox::mouseMoveEvent ( QGraphicsSceneMouseEvent * event )
{

   QPointF newPos = event->pos() ;
   _location += (newPos - _dragStart);
   this->setPos(_location);
}

void StateBox::hoverLeaveEvent ( QGraphicsSceneHoverEvent * )
{
    _outterborderColor = Qt::black;
    this->update(0,0,_width,_height);
}

void StateBox::hoverEnterEvent ( QGraphicsSceneHoverEvent * )
{
    _outterborderColor = Qt::red;
    this->update(0,0,_width,_height);
}

QRectF StateBox::boundingRect() const
{

    return QRectF(0,0,_width,_height);
}


// example of a drop shadow effect on a box, using QLinearGradient and two boxes

void StateBox::paint (QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
{

    /*
     The drop shadow effect will be created by drawing a filled, rounded corner rectangle with a gradient fill.
     Then on top of this will be drawn  filled, rounded corner rectangle, filled with a solid color, and offset such that the gradient filled
     box is only visible below for a few pixels on two edges.

     The total box size is _width by _height. So the top box will start at (0,0) and go to (_width-shadowThickness, _height-shadowThickness),
     while the under box will be offset, and start at (shadowThickness+0, shadowThickness+0) and go to  (_width, _height).
       */

    int shadowThickness = 3;

    QLinearGradient gradient;
    gradient.setStart(0,0);
    gradient.setFinalStop(_width,0);
    QColor grey1(150,150,150,125);// starting color of the gradient - can play with the starting color and ,point since its not visible anyway

    // grey2 is ending color of the gradient - this is what will show up as the shadow. the last parameter is the alpha blend, its set
    // to 125 allowing a mix of th color and and the background, making more realistic shadow effect.
    QColor grey2(225,225,225,125);


    gradient.setColorAt((qreal)0, grey1 );
    gradient.setColorAt((qreal)1, grey2 );

    QBrush brush(gradient);

    painter->setBrush( brush);

    // for the desired effect, no border will be drawn, and because a brush was set, the drawRoundRect will fill the box with the gradient brush.
    _outterborderPen.setStyle(Qt::NoPen);
    painter->setPen(_outterborderPen);

    QPointF topLeft (shadowThickness+0, shadowThickness+0);
    QPointF bottomRight ( _width, _height);

    QRectF rect (topLeft, bottomRight);

    painter->drawRoundRect(rect,25,25); // corner radius of 25 pixels

    // draw the top box, the visible one
    QBrush brush2(QColor(255,250,200,255),Qt::SolidPattern);

    painter->setBrush( brush2);

    QPointF topLeft2 (0, 0);
    QPointF bottomRight2 ( _width-shadowThickness, _height-shadowThickness);

    QRectF rect2 (topLeft2, bottomRight2);

    painter->drawRoundRect(rect2,25,25);
}
